@@ -48,4 +48,11 @@ rdelap <-
       }
     }
     return(RDLAP)
+  }
+
+MoMdelap <- function (x) {
+    MoMDLAP <- vector(length = 3, mode = "numeric")
+    MoMDLAP <- MoMdelap_C(x)
+    if (any(MoMDLAP < 0)) stop ("Method of moments not appropriate for this data; results include negative parameters.")
+    return(MoMDLAP)
   }
\ No newline at end of file
